
=============  =============  ====================  =======  =======================================================================================================================================================================================================================================================================================================================================================================================
Key            Type           Options               Default  Description                                                                                                                                                                                                                                                                                                                                                                            
=============  =============  ====================  =======  =======================================================================================================================================================================================================================================================================================================================================================================================
``index``      int            ..                    ..       An index used to refer to the bandpass filter                                                                                                                                                                                                                                                                                                                                          
``name``       str            ..                    ..       A name for the bandpass filter                                                                                                                                                                                                                                                                                                                                                         
``restwave``   int, float     ..                    ..       The rest wavelength of the line in the primary passband in angstroms **in vacuum**.  This is used to convert the first and second moments to velocity (km/s) for emission lines.                                                                                                                                                                                                       
``primary``    ndarray, list  ..                    ..       A two-element vector with the starting and ending wavelength (angstroms in **vacuum**) for a passband to the blue of the primary spectral feature.                                                                                                                                                                                                                                     
``blueside``   ndarray, list  ..                    ..       A two-element vector with the starting and ending wavelength (angstroms in **vacuum**) for a passband to the red of the primary spectral feature.                                                                                                                                                                                                                                      
``redside``    ndarray, list  ..                    ..       A two-element vector with the starting and ending wavelength (angstroms in **vacuum**) for the primary passband surrounding the spectral feature of interest.  This is used by :class:`mangadap.par.emissionmomentsdb.EmissionMomentsDB` and :class:`mangadap.par.absorptionindexdb.AbsorptionIndexDB`, but it is irrelevant for :class:`mangadap.par.bandheadindexdb.BandheadIndexDB`.
``units``      str            ``ang``, ``mag``      ..       Define the unit for the spectral index as either angstroms (``ang``) or magnitudes (``mag``).  Currently only used by :class:`mangadap.par.absorptionindexdb.AbsorptionIndexDB`.                                                                                                                                                                                                       
``component``  bool           ..                    ..       Flag that the bandpass definition is a component of a larger set of bandpass filters.  This is currently only used by :class:`mangadap.par.absorptionindexdb.AbsorptionIndexDB` to combine index measurements into a single index.  If True, all components with the same *name* are summed to form the composite index.                                                               
``integrand``  str            ``flambda``, ``fnu``  ..       Currently only used by :class:`mangadap.par.bandheadindexdb.BandheadIndexDB`.  Define the integrand over the passband used to construct and index as either flux per unit frequency (``fnu``), :math:`F_\nu`, or flux per unit wavelength (``flambda``), :math:`F_\lambda`.                                                                                                            
``order``      str            ``b_r``, ``r_b``      ..       Currently only used by :class:`mangadap.par.bandheadindexdb.BandheadIndexDB`.  Define the order to use when constructing the index.  The options are either a ratio of red-to-blue or blue-to-red, which are respectively selected using ``r_b`` or ``b_r``.                                                                                                                           
=============  =============  ====================  =======  =======================================================================================================================================================================================================================================================================================================================================================================================

